@@ -5,7 +5,7 @@ define([
     , 'nbextensions/visualpython/src/common/constant'
     , 'nbextensions/visualpython/src/common/StringBuilder'
 ], function (requirejs, $, vpCommon, vpConst, sb) {
-    let _componentID;
+    let _UUID;
 
     /**
      * @interface vpComComponent 컴퍼넌트 인터페이스
@@ -19,7 +19,7 @@ define([
      * 컨트롤 uuid 생성
      */
     vpComComponent.prototype.setUUID = function() {
-        this._componentID = vpCommon.getUUID();
+        this._UUID = vpCommon.getUUID();
     }
 
     /**
@@ -33,8 +33,8 @@ define([
      * vp wrap selector string
      * @param {String} id 최종 tag id
      */
-    vpComComponent.prototype.wrapSelector = function(selector) {
-        return vpCommon.wrapSelector(vpCommon.formatString(".{0} {1}", this._componentID, selector));
+    vpComComponent.prototype.wrapSelector = function(selector = "") {
+        return vpCommon.wrapSelector(vpCommon.formatString(".{0} {1}", this._UUID, selector));
     }
     
     return {
