@@ -1,7 +1,8 @@
 define ([
     'nbextensions/visualpython/src/numpy/common/NumpyPageRender/parent/NumpyPageRender'
-], function(  NumpyPageRender ) {
-
+    , 'nbextensions/visualpython/src/numpy/constData'
+], function(  NumpyPageRender, constData ) {
+    const { STR_INPUT_NUMBER } = constData;
     'use strict';
     /**
      * @class NpArangePageRender
@@ -41,7 +42,7 @@ define ([
                     , numpyPageRenderFuncType: PARAM_INPUT_EDITOR_TYPE
                     , stateParamNameStrOrStrArray: [stateParamNameStrArray[0]]
                     , paramNameStrArray: ['start']
-                    , placeHolderArray: ['숫자 입력']
+                    , placeHolderArray: [STR_INPUT_NUMBER]
                 }
             },
             {
@@ -52,7 +53,7 @@ define ([
                     , numpyPageRenderFuncType: PARAM_INPUT_EDITOR_TYPE
                     , stateParamNameStrOrStrArray: [ stateParamNameStrArray[1], stateParamNameStrArray[2]]
                     , paramNameStrArray: ['start', 'stop']
-                    , placeHolderArray: ['숫자 입력', '숫자 입력']
+                    , placeHolderArray: [STR_INPUT_NUMBER, STR_INPUT_NUMBER]
                 }
            
             },
@@ -64,7 +65,7 @@ define ([
                     , numpyPageRenderFuncType: PARAM_INPUT_EDITOR_TYPE
                     , stateParamNameStrOrStrArray:  [ stateParamNameStrArray[3], stateParamNameStrArray[4], stateParamNameStrArray[5]]
                     , paramNameStrArray: ['start', 'stop', 'step']
-                    , placeHolderArray: ['숫자 입력', '숫자 입력', '숫자 입력']
+                    , placeHolderArray: [STR_INPUT_NUMBER, STR_INPUT_NUMBER, STR_INPUT_NUMBER]
                 }
             
             }
