@@ -1,13 +1,8 @@
 define ([
-    'require'
-    , 'nbextensions/visualpython/src/common/vpCommon'
-    // numpy 패키지를 위한 라이브러리import 
-    , 'nbextensions/visualpython/src/common/constant_numpy'
-    , 'nbextensions/visualpython/src/numpy/common/NumpyPageRender/parent/NumpyPageRender'
-], function( requirejs, vpCommon, 
-             vpNumpyConst, NumpyPageRender ) {
+    'nbextensions/visualpython/src/numpy/common/NumpyPageRender/parent/NumpyPageRender'
+], function( NumpyPageRender ) {
 
-    "use strict";
+    'use strict';
     /**
      * @class NpFlipPageRender
      * @constructor
@@ -38,8 +33,11 @@ define ([
 
         /** 옵션 창 */
         this.renderAdditionalOptionContainer();
-        this.renderSelectIndexValueBlock("select Axis", "axis");
+        this.renderSelectIndexValueBlock('select Axis', 'axis');
         this.renderReturnVarBlock();
+        
+        /** userOption 창 */
+        this.renderUserOption();
 
         this.renderPostfixCode();
     }
