@@ -1,12 +1,8 @@
 define ([
-    'require'
-    , 'nbextensions/visualpython/src/common/vpCommon'
-    // numpy 패키지를 위한 라이브러리import 
-    , 'nbextensions/visualpython/src/numpy/common/NumpyPageRender/parent/NumpyPageRender'
-], function( requirejs, vpCommon, 
-             NumpyPageRender ) {
+    'nbextensions/visualpython/src/numpy/common/NumpyPageRender/parent/NumpyPageRender'
+], function( NumpyPageRender ) {
 
-    "use strict";
+    'use strict';
     /**
      * @class NpZerosOnesEmptyPageRender
      * @constructor
@@ -38,34 +34,34 @@ define ([
         const { PARAM_ONE_ARRAY_EDITOR_TYPE, PARAM_TWO_ARRAY_EDITOR_TYPE,
                 PARAM_THREE_ARRAY_EDITOR_TYPE, PARAM_INPUT_EDITOR_TYPE, PARAM_ONE_ARRAY_INDEX_N_EDITOR_TYPE } = this.numpyEnumRenderEditorFuncType;
         // state의 paramData 객체의 키값을 string 배열로 리턴
-        var stateParamNameStrArray = Object.keys(this.numpyStateGenerator.getState("paramData"));
-        var tabTitle = "Input Parameter";
+        var stateParamNameStrArray = Object.keys(this.numpyStateGenerator.getState('paramData'));
+        var tabTitle = 'Input Parameter';
         var tabBlockArray = [
             {
                 tabNumber: 1
-                , btnText: "1D Array "
+                , btnText: '1D Array '
                 , bindFuncData: {
                     numpyPageRenderThis: numpyPageRenderThis
                     , numpyPageRenderFuncType: PARAM_INPUT_EDITOR_TYPE
                     , stateParamNameStrOrStrArray: [stateParamNameStrArray[0]]
-                    , paramNameStrArray: ["길이"]
-                    , placeHolderArray: ["숫자 입력"]
+                    , paramNameStrArray: ['길이']
+                    , placeHolderArray: ['숫자 입력']
                 }
             },
             {
                 tabNumber: 2
-                , btnText: "2D Array"
+                , btnText: '2D Array'
                 , bindFuncData: {
                     numpyPageRenderThis: numpyPageRenderThis
                     , numpyPageRenderFuncType: PARAM_INPUT_EDITOR_TYPE
                     , stateParamNameStrOrStrArray: [ stateParamNameStrArray[1], stateParamNameStrArray[2]]
-                    , paramNameStrArray: ["행", "열"]
-                    , placeHolderArray: ["숫자 입력", "숫자 입력"]
+                    , paramNameStrArray: ['행', '열']
+                    , placeHolderArray: ['숫자 입력', '숫자 입력']
                 }
             },
             {
                 tabNumber: 3
-                , btnText: "ND Array"
+                , btnText: 'ND Array'
                 , bindFuncData: {
                     numpyPageRenderThis: numpyPageRenderThis
                     , numpyPageRenderFuncType: PARAM_ONE_ARRAY_INDEX_N_EDITOR_TYPE
