@@ -1,13 +1,8 @@
 define ([
-    'require'
-    , 'nbextensions/visualpython/src/common/vpCommon'
-    // numpy 패키지를 위한 라이브러리import 
-    , 'nbextensions/visualpython/src/common/constant_numpy'
-    , 'nbextensions/visualpython/src/numpy/common/NumpyPageRender/parent/NumpyPageRender'
-], function( requirejs, vpCommon, 
-             vpNumpyConst, NumpyPageRender ) {
+    'nbextensions/visualpython/src/numpy/common/NumpyPageRender/parent/NumpyPageRender'
+], function( NumpyPageRender ) {
 
-    "use strict";
+    'use strict';
     /**
      * @class UnaryArimethicPageRender
      * @constructor
@@ -38,14 +33,14 @@ define ([
         var numpyStateGenerator = this.numpyStateGenerator;
         var numpyPageRenderThis = this;
         // state의 paramData 객체의 키값을 string 배열로 리턴
-        var stateParamNameStrArray = Object.keys(numpyStateGenerator.getState("paramData"));
-        var tabTitle = "Input Parameter";
+        var stateParamNameStrArray = Object.keys(numpyStateGenerator.getState('paramData'));
+        var tabTitle = 'Input Parameter';
         const { PARAM_ONE_ARRAY_EDITOR_TYPE, PARAM_TWO_ARRAY_EDITOR_TYPE,
                PARAM_THREE_ARRAY_EDITOR_TYPE, PARAM_INPUT_EDITOR_TYPE } = this.numpyEnumRenderEditorFuncType;
         var tabBlockArray = [
             {
                 tabNumber: 1
-                , btnText: "1D Array"
+                , btnText: '1D Array'
                 , bindFuncData: {
                     numpyPageRenderThis: numpyPageRenderThis
                     , numpyPageRenderFuncType: PARAM_ONE_ARRAY_EDITOR_TYPE
@@ -54,7 +49,7 @@ define ([
             },
             {
                 tabNumber: 2
-                , btnText: "2D Array"
+                , btnText: '2D Array'
                 , bindFuncData: {
                     numpyPageRenderThis: numpyPageRenderThis
                     , numpyPageRenderFuncType: PARAM_TWO_ARRAY_EDITOR_TYPE
@@ -63,7 +58,7 @@ define ([
             },
             {
                 tabNumber: 3
-                , btnText: "3D Array"
+                , btnText: '3D Array'
                 , bindFuncData: {
                     numpyPageRenderThis: numpyPageRenderThis
                     , numpyPageRenderFuncType: PARAM_THREE_ARRAY_EDITOR_TYPE
@@ -72,24 +67,24 @@ define ([
             },
             {
                 tabNumber: 4
-                , btnText: "Scalar Value"
+                , btnText: 'Scalar Value'
                 , bindFuncData: {
                     numpyPageRenderThis: numpyPageRenderThis
                     , numpyPageRenderFuncType: PARAM_INPUT_EDITOR_TYPE
                     , stateParamNameStrOrStrArray: [ stateParamNameStrArray[3] ]
-                    , paramNameStrArray: ["스칼라 값"]
-                    , placeHolderArray: ["숫자 입력"]
+                    , paramNameStrArray: ['스칼라 값']
+                    , placeHolderArray: ['숫자 입력']
                 }
             },
             {
                 tabNumber: 5
-                , btnText: "Param Variable"
+                , btnText: 'Param Variable'
                 , bindFuncData: {
                     numpyPageRenderThis: numpyPageRenderThis
                     , numpyPageRenderFuncType: PARAM_INPUT_EDITOR_TYPE
                     , stateParamNameStrOrStrArray: [ stateParamNameStrArray[4] ]
-                    , paramNameStrArray: ["변수"]
-                    , placeHolderArray: ["변수 입력"]
+                    , paramNameStrArray: ['변수']
+                    , placeHolderArray: ['변수 입력']
                 }
             }
         ];
