@@ -4,7 +4,8 @@ define ([
 
     "use strict";
 
-    var { _renderParamArrayEditorTitle, _resetArrayEditor, _renderEditorModalOpenBtn,
+    var { _renderParamArrayEditorTitle, _resetArrayEditor, 
+        //   _renderEditorModalOpenBtn,
           _renderParamTabBlock, _renderParamOneArrayEditor, _renderParamTwoArrayEditor,
           _renderParamThreeArrayEditor,
           _renderParamOneArrayIndexValueEditor,
@@ -41,6 +42,8 @@ define ([
 
         this.funcName = ``;
     };
+
+    /** ------------------------------------------------------------------------------------------------------------ */
     /**
      * @publicMethod
 
@@ -50,10 +53,11 @@ define ([
     * nummpy 패키지에서 page를 렌더하는 메소드.
     * @param {this} importPackageThis 
     */
-
     NumpyPageRender.prototype.pageRender = function() {
 
     }
+
+    /** ------------------------------------------------------------------------------------------------------------ */
     NumpyPageRender.prototype.setMainPageSelector = function(mainPageSelector) {
         this.mainPageSelector = mainPageSelector;
     }
@@ -127,24 +131,36 @@ define ([
         return this.paletteConfirmButton;
     }
 
+    /** ------------------------------------------------------------------------------------------------------------ */
     /**
      * 1차원 배열의 길이를 가져온다
      */
     NumpyPageRender.prototype.getOneArrayLength= function() {
         return this.oneArrayLength;
     }
+    NumpyPageRender.prototype.setOneArrayLength = function(oneArrayLength) {
+        return this.oneArrayLength = oneArrayLength;
+    }
+    
     /**
      * 2차원 배열의 행을 가져온다
      */
     NumpyPageRender.prototype.getTwoArrayRow = function() {
         return this.twoArrayRow;
     }
-     /**
-     * 2차원 배열의 열을 가져온다
-     */
     NumpyPageRender.prototype.getTwoArrayCol = function() {
         return this.twoArrayCol;
     }
+    NumpyPageRender.prototype.setTwoArrayRow = function(twoArrayRow) {
+        return this.twoArrayRow = twoArrayRow;
+    }
+    NumpyPageRender.prototype.setTwoArrayCol = function(twoArrayCol) {
+        return this.twoArrayCol = twoArrayCol;
+    }
+
+    /**
+     * 3차원 배열의 열을 가져온다
+     */
     NumpyPageRender.prototype.getThreeArrayRow = function() {
         return this.threeArrayRow;
     }
@@ -154,17 +170,6 @@ define ([
     NumpyPageRender.prototype.getThreeArrayDepth = function() {
         return this.threeArrayDepth;
     }
-
-
-    NumpyPageRender.prototype.setOneArrayLength = function(oneArrayLength) {
-        return this.oneArrayLength = oneArrayLength;
-    }
-    NumpyPageRender.prototype.setTwoArrayRow = function(twoArrayRow) {
-        return this.twoArrayRow = twoArrayRow;
-    }
-    NumpyPageRender.prototype.setTwoArrayCol = function(twoArrayCol) {
-        return this.twoArrayCol = twoArrayCol;
-    }
     NumpyPageRender.prototype.setThreeArrayRow = function(threeArrayRow ) {
         return this.threeArrayRow = threeArrayRow;
     }
@@ -174,26 +179,31 @@ define ([
     NumpyPageRender.prototype.setThreeArrayDepth = function(threeArrayDepth) {
         return this.threeArrayDepth = threeArrayDepth;
     }
+
+
+
+
+    // /**
+    //  * renderEditorModalOpenBtn
+    //  * @param {Document} baseDom 
+    //  * @param {string} buttonTagSelector 
+    //  * @param {string} funcId 
+    //  * @param {string} flexType // row or column
+    //  * @param {string} stateParamName 
+    //  * @param {string} tagSelector 
+    //  * 배열 편집기 모달창을 오픈하는 버튼을 생성한다
+    //  */
+
+    // NumpyPageRender.prototype.renderEditorModalOpenBtn = function (baseDom, buttonTagSelector, funcId, flexType, stateParamName,tagSelector) {
+    //     var numpyPageRendererThis = this;
+    //     _renderEditorModalOpenBtn(numpyPageRendererThis, baseDom, buttonTagSelector, funcId, flexType, stateParamName,tagSelector);
+    // }
+
+
+    /** ------------------------------------------------------------------------------------------------------------ */
     /**
      * @priavteMethod
-    */
-
-    /**
-     * renderEditorModalOpenBtn
-     * @param {Document} baseDom 
-     * @param {string} buttonTagSelector 
-     * @param {string} funcId 
-     * @param {string} flexType // row or column
-     * @param {string} stateParamName 
-     * @param {string} tagSelector 
-     * 배열 편집기 모달창을 오픈하는 버튼을 생성한다
      */
-
-    NumpyPageRender.prototype.renderEditorModalOpenBtn = function (baseDom, buttonTagSelector, funcId, flexType, stateParamName,tagSelector) {
-        var numpyPageRendererThis = this;
-        _renderEditorModalOpenBtn(numpyPageRendererThis, baseDom, buttonTagSelector, funcId, flexType, stateParamName,tagSelector);
-    }
-
     /** getPaletteConfirmButton 
      * 태그를 전부 리셋 empty
      */
