@@ -32,12 +32,14 @@ define ([
             (function(j) {
                 var stateElement = numpyStateGenerator.getState(stateParamName)[j];
                 var narrayBlockDiv = renderDiv({'class': 'vp-numpy-style-flex-row'});
-                var narrayBlockIndexDiv = renderDiv({'class': `vp-numpy-style-flex-column-center vp-numpy-style-font-weight-700 margin-right-5px`
+                var narrayBlockIndexDiv = renderDiv({'class': `vp-numpy-style-flex-column-center 
+                                                               vp-numpy-style-font-weight-700 
+                                                               margin-right-5px`
                                                      , 'text': `N${j+1}`});
                 var narrayBlockInput = renderInput({'class': 'vp-numpy-input'
                                                      , 'value': `${stateElement}`
                                                      , 'type': 'text'
-                                                     , 'placeholder': '입력'});
+                                                     , 'placeholder': 'Input'});
                 var deleteButton = renderButton({'class':'vp-numpy-func_btn'
                                                  , 'text':'x'});
 
