@@ -12,12 +12,12 @@ define ([
         var optionPage = $(numpyPageRendererThis.importPackageThis.wrapSelector(rootTagSelector));
         var additionalOptionDomElement = $(`<div class='vp-numpy-requiredPageBlock-view 
                                                         vp-numpy-block '>
-                                                <h4>
-                                                    <div class='vp-panel-area-vertical-btn vp-arrow-up'></div>
+                                                <div class="vp-accordion-header">
+                                                    <div class='vp-panel-area-vertical-btn vp-arrow-right'></div>
                                                     <span class='vp-multilang' data-caption-id='TODO:Variable'>
                                                         Required Input &amp; Output
                                                     </span>
-                                                </h4>
+                                                </div>
                                             </div>`);
 
         optionPage.append(additionalOptionDomElement);
