@@ -9,19 +9,21 @@ define([
     , 'nbextensions/visualpython/src/numpy/constant_numpy'
     , 'nbextensions/visualpython/src/numpy/api/numpyStateApi'
     , 'nbextensions/visualpython/src/numpy/api/numpyRouteMapApi'
-
+    , 'nbextensions/visualpython/src/numpy/api/numpyValidatorApi'
+    , 'nbextensions/visualpython/src/numpy/constData'
 ], function ( requirejs, $, vpCommon, vpConst, vpFuncJS, 
-              vpNumpyConst, numpyStateApi, numpyRouteMapApi ) {
+              vpNumpyConst, numpyStateApi, numpyRouteMapApi, numpyValidatorApi, numpyConstData ) {
     // 옵션 속성
     const funcOptProp = {
         stepCount : 1
         , funcName : "np.ravel"
         , funcID : "JY24"  // TODO: ID 규칙 생성 필요
     }
-
+    /** numpy에서 사용하는 constData */
+    const { VP_ID_PREFIX, VP_CLASS_PREFIX } = numpyConstData;
     // FuncId에 맞는 FuncData를 맵핑하는 api
-    var { newMapFuncIdToNumpyFuncData, mapFuncIdToHtmlUrlPath } = numpyRouteMapApi;
-    
+    const { newMapFuncIdToNumpyFuncData, mapFuncIdToHtmlUrlPath } = numpyRouteMapApi;
+    const { validateNumpyState } = numpyValidatorApi;
     /**
      * html load 콜백. 고유 id 생성하여 부과하며 js 객체 클래스 생성하여 컨테이너로 전달
      * @param {function} callback 호출자(컨테이너) 의 콜백함수
@@ -38,7 +40,7 @@ define([
                     uuid = vpCommon.getUUID();
                 }
             }
-            $(vpCommon.wrapSelector(vpConst.OPTION_GREEN_ROOM)).find(vpConst.OPTION_PAGE).addClass(uuid);
+            $(vpCommon.wrapSelector(`${VP_ID_PREFIX}${vpConst.OPTION_GREEN_ROOM}`)).find(`${VP_CLASS_PREFIX}${vpConst.API_OPTION_PAGE}`).addClass(uuid);
             // 옵션 객체 생성
             var ipImport = new ImportPackage(uuid);
             // 옵션 속성 할당.
@@ -55,7 +57,7 @@ define([
     */
     var initOption = function(callback) {
         var htmlUrlPath  = mapFuncIdToHtmlUrlPath(funcOptProp.funcID);
-        vpCommon.loadHtml(vpCommon.wrapSelector(vpConst.OPTION_GREEN_ROOM), htmlUrlPath, optionLoadCallback, callback);
+        vpCommon.loadHtml(vpCommon.wrapSelector(`${VP_ID_PREFIX}${vpConst.OPTION_GREEN_ROOM}`), htmlUrlPath, optionLoadCallback, callback);
     }
 
     /**
@@ -65,7 +67,7 @@ define([
     var ImportPackage = function(uuid) {
         this.uuid = uuid; // Load html 영역의 uuid.
         this.numpyCodeGenerator  // numpyCodeGenerator은 코드를 만듬
-        this.numpyCodeValidator // numpyCodeValidator은 코드 실행 전 입력된 state 값을 검증
+        // this.numpyCodeValidator // numpyCodeValidator은 코드 실행 전 입력된 state 값을 검증
         this.numpyPageRender // numpyPageRender는 동적 html을 index.html에 렌더링
         this.numpyStateGenerator // numpyStateGenerator는 state를 생성, 변경 
     }
@@ -80,10 +82,8 @@ define([
         * @returns 유효성 검사 결과. 적합시 true
     */
     ImportPackage.prototype.optionValidation = function() {
-        // numpyPageRender안에 numpyStateGenerator의 this를 데이터로 담아 있는 상태에서
-        // numpyStateGenerator의 getStateAll 메소드를 호출하여 state를 가져온다음
         // state 데이터를 validation 한다
-        return this.numpyCodeValidator.validate(this.numpyStateGenerator.getStateAll());
+        return validateNumpyState()
     }
 
     /**
@@ -91,11 +91,11 @@ define([
         */
     ImportPackage.prototype.initHtml = function() {
         var { numpyCodeGenerator
-            , numpyCodeValidator
+            // , numpyCodeValidator
             , numpyPageRender
             , numpyStateGenerator } = newMapFuncIdToNumpyFuncData(funcOptProp.funcID, funcOptProp.funcName);
         this.numpyCodeGenerator = numpyCodeGenerator;
-        this.numpyCodeValidator = numpyCodeValidator;
+        // this.numpyCodeValidator = numpyCodeValidator;
         this.numpyPageRender = numpyPageRender;
         this.numpyStateGenerator = numpyStateGenerator;
 
