@@ -7,13 +7,13 @@ define([
     , 'nbextensions/visualpython/src/common/vpFuncJS'
 
     // numpy 패키지를 위한 라이브러리import 
-    , 'nbextensions/visualpython/src/common/constant_numpy'
+    , 'nbextensions/visualpython/src/numpy/constant_numpy'
     , 'nbextensions/visualpython/src/numpy/api/numpyStateApi'
     , 'nbextensions/visualpython/src/numpy/api/numpyRouteMapApi'
-    , 'nbextensions/visualpython/src/numpy/api/NumpyCommonApi'
+    , 'nbextensions/visualpython/src/numpy/api/numpyValidatorApi'
 
 ], function ( requirejs, $, vpCommon, vpConst, sb, vpFuncJS, 
-              vpNumpyConst, numpyStateApi, numpyRouteMapApi, NumpyCommonApi ) {
+              vpNumpyConst, numpyStateApi, numpyRouteMapApi, numpyValidatorApi ) {
     // 옵션 속성
     const funcOptProp = {
         stepCount : 1
@@ -22,8 +22,8 @@ define([
     }
 
     // FuncId에 맞는 FuncData를 맵핑하는 api
-    var { newMapFuncIdToNumpyFuncData, mapFuncIdToHtmlUrlPath } = numpyRouteMapApi;
-
+    const { newMapFuncIdToNumpyFuncData, mapFuncIdToHtmlUrlPath } = numpyRouteMapApi;
+    const { validateNumpyState } = numpyValidatorApi;
 
     /**
      * html load 콜백. 고유 id 생성하여 부과하며 js 객체 클래스 생성하여 컨테이너로 전달
@@ -69,7 +69,7 @@ define([
     var ImportPackage = function(uuid) {
         this.uuid = uuid; // Load html 영역의 uuid.
         this.numpyCodeGenerator  // numpyCodeGenerator은 코드를 만듬
-        this.numpyCodeValidator // numpyCodeValidator은 코드 실행 전 입력된 state 값을 검증
+        // this.numpyCodeValidator // numpyCodeValidator은 코드 실행 전 입력된 state 값을 검증
         this.numpyPageRender // numpyPageRender는 동적 html을 index.html에 렌더링
         this.numpyStateGenerator // numpyStateGenerator는 state를 생성, 변경 
     }
@@ -84,12 +84,8 @@ define([
      * @returns 유효성 검사 결과. 적합시 true
      */
     ImportPackage.prototype.optionValidation = function() {
-        // numpyPageRender안에 numpyStateGenerator의 this를 데이터로 담아 있는 상태에서
-        // numpyStateGenerator의 getStateAll 메소드를 호출하여 state를 가져온다음
         // state 데이터를 validation 한다
-        return this.numpyCodeValidator.validate(this.numpyStateGenerator.getStateAll());
-        // 부모 클래스 유효성 검사 호출.
-        // vpFuncJS.VpFuncJS.prototype.optionValidation.apply(this);
+        return validateNumpyState();
     }
 
     /**
@@ -97,11 +93,11 @@ define([
      */
     ImportPackage.prototype.initHtml = function() {
         var { numpyCodeGenerator
-            , numpyCodeValidator
+            // , numpyCodeValidator
             , numpyPageRender
             , numpyStateGenerator } = newMapFuncIdToNumpyFuncData(funcOptProp.funcID);
         this.numpyCodeGenerator = numpyCodeGenerator;
-        this.numpyCodeValidator = numpyCodeValidator;
+        // this.numpyCodeValidator = numpyCodeValidator;
         this.numpyPageRender = numpyPageRender;
         this.numpyStateGenerator = numpyStateGenerator;
 
