@@ -1,26 +1,29 @@
 define([
     'require'
     , 'jquery'
-    ,'nbextensions/visualpython/src/common/vpCommon'
+    , 'nbextensions/visualpython/src/common/vpCommon'
+    , 'nbextensions/visualpython/src/common/vpMakeDom'
     , 'nbextensions/visualpython/src/common/StringBuilder'
     //
-    , 'nbextensions/visualpython/src/component/api/componentConstApi'
+    , 'nbextensions/visualpython/src/component/fileNavigation/api'
     , 'nbextensions/visualpython/src/component/fileNavigation/executor'
-], function ( requirejs, $, vpCommon, sb,
-              componentConstApi, fileNavigationExecutorFuncList) {
-    
+    , 'nbextensions/visualpython/src/component/fileNavigation/constData'
+], function ( requirejs, $, vpCommon, vpMakeDom, sb,
+              componentConstApi, executor, constData) {
+
+    const { NAVIGATION_DIRECTION_TYPE } = constData;
     // kernel executor에 필요한 함수 import
-    var { executeKernelFromDir,
-          executeKernelFromDirRightBody } = fileNavigationExecutorFuncList;
+    const { executeKernelFromDir,
+            executeKernelFromDirBody } = executor;
     // dom 만드는데 필요한 함수 import
-    var { makeDom, controlToggleInput, closeComponent } = componentConstApi;
+    const { controlToggleInput } = componentConstApi;
+    const { renderSpan, renderLi } = vpMakeDom;
     // stringBuilder import
-    var sbCode = new sb.StringBuilder();
+    // var sbCode = new sb.StringBuilder();
 
     var FileNavigationRenderer = function(fileNavigationState, vpFuncJS, fileResultState) {
         this.fileNavigationState = fileNavigationState;
         this.vpFuncJS = vpFuncJS;
-
         this.fileResultState = fileResultState;
     }
 
@@ -32,13 +35,13 @@ define([
     FileNavigationRenderer.prototype.initRender = function() {
         var fileNavigationRendererThis = this;
         var dirObj = {
-            direction: 'init',
+            direction: NAVIGATION_DIRECTION_TYPE.INIT,
         }
  
         executeKernelFromDir(dirObj, fileNavigationRendererThis);
 
         /** fileNavigation right tab에 현재 path의 폴더와 파일들 렌더링 */
-        executeKernelFromDirRightBody(dirObj, fileNavigationRendererThis);
+        executeKernelFromDirBody(dirObj, fileNavigationRendererThis);
 
         /** 만약 타입이 'SAVE_FILE'일 경우' */
         var fileNavigationState = fileNavigationRendererThis.getFileNavigationState();
@@ -47,9 +50,13 @@ define([
 
         /** Pandas > File IO > to_csv(), to_excel(), to_json(), to_pickle() 네비게이션 클릭시 */
         if(fileNavigationtype === 'SAVE_FILE'){
+
+            /** 20201118 이진용 주임 수정 */
+            /** 현재 디렉토리에 파일 저장 -> Save file to current directory */
+            /** 파일 이름 입력 -> Input file name */
             var saveFileDataBtn = $(`<button class='directoryComponent-btn-saveVisualPython'
-                                                 style='margin-left: 10px;'>현재 디렉토리에 파일 저장</button>`);
-            var saveFileDataInput = $(`<input id='vp-fileNavigation' type='text' placeholder='파일 이름 입력'></input>`);
+                                                 style='margin-left: 10px;'>Save file to current directory</button>`);
+            var saveFileDataInput = $(`<input id='vp-fileNavigation' type='text' placeholder='Input file name'></input>`);
             $('.directoryComponent-savebutton').append(saveFileDataInput);
             $('.directoryComponent-savebutton').append(saveFileDataBtn);
          
@@ -63,7 +70,9 @@ define([
              */
             $(saveFileDataBtn).click(function(){
                 if(fileNavigationState.getVisualPythonFileName() === ``){
-                    vpCommon.renderAlertModal('File 이름을 입력해주세요');
+                    /** 20201118 이진용 주임 수정 */
+                    /** File 이름을 입력해주세요 -> Please input file name */
+                    vpCommon.renderAlertModal('Please input file name');
                     return;
                 }
                 var dirPath = fileNavigationRendererThis.makeNewCurrRelativePath();
@@ -85,7 +94,7 @@ define([
 
         var currentDirRootDom = $(`<div class='directoryComponent-right scrollbar'>
                                   </div>`);
-        var { folderArr } = this.makeFolderOrFileDomArr(dirInfoArr, 'init');
+        var { folderArr } = this.makeFolderOrFileDomArr(dirInfoArr);
     
         currentDirRootDom.appendTo('.directoryComponent-container');
         var directoryComponentUl = $('.directoryComponent-ul');
@@ -94,22 +103,14 @@ define([
         });
     }
 
-    /** */
-    FileNavigationRenderer.prototype.renderCurrentDirPathInfoLeftTab = function(dirInfoArr, rootDom) {
-        var { folderArr } = this.makeFolderOrFileDomArr(dirInfoArr , 'tab');
-        folderArr.forEach(folder => {
-            rootDom.appendChild(folder);
-        });
-    }
-
     /** */
     FileNavigationRenderer.prototype.renderCurrentDirPathInfoRightBody = function(dirInfoArr, rootFolderName) {
         $('.directoryComponent-right').empty();
         var currentDirRootDom = $(`<div class='directoryComponent-body'></div>`);
-        var { folderArr, fileArr } = this.makeFolderOrFileDomArr(dirInfoArr, 'body');
+        var { folderArr, fileArr } = this.makeFolderOrFileDomArr(dirInfoArr);
         
         var directoryComponentUl = $(`<ul class='directoryComponent-ul'>
-                                    </ul>`);
+                                      </ul>`);
   
         folderArr.forEach(dom => {
             directoryComponentUl.append(dom);
@@ -122,72 +123,56 @@ define([
     }
 
     /** <div/> 태그 형식의 폴더 디렉토리를 만드는 함수 */
-    FileNavigationRenderer.prototype.makeFolderDom = function(node, renderDomType) {
+    FileNavigationRenderer.prototype.makeFolderDom = function(node) {
         var fileNavigationRendererThis = this;
 
         var folderName = node.name;
         var folderPath = node.path;
 
-        var directoryLi = makeDom('li', {
-            classList: 'directoryComponent-li'
-        });
-
-        var directorySpan = makeDom('span', {
-            classList: 'directoryComponent-column'
-        });
- 
-        var directorySpanDir = makeDom('span', {
-            innerHTML: `${folderName}`,
-            classList: 'directoryComponent-dir-text icon-folder'
-        });
+        var directoryLi = renderLi({class: 'directoryComponent-li'});
+        var directorySpan = renderSpan({class:'directoryComponent-column'});
+        var directorySpanDir = renderSpan({class:'directoryComponent-dir-text icon-folder'
+                                            ,text: `${folderName}`});
   
-        directorySpanDir.addEventListener('click', function() {
+        $(directorySpanDir).click(function() {
             var dirObj = {
-                direction: 'to',
+                direction: NAVIGATION_DIRECTION_TYPE.TO,
                 destDir: folderPath
             }
-
-            executeKernelFromDirRightBody(dirObj, fileNavigationRendererThis);
+            executeKernelFromDirBody(dirObj, fileNavigationRendererThis);
         });
 
-        directoryLi.appendChild(directorySpan.appendChild(directorySpanDir));
-            
+        $(directoryLi).append($(directorySpan).append(directorySpanDir));
         return directoryLi;
     }
+
     /**  <div/> 태그 형식의 파일 디렉토리를 만드는 함수 */
     FileNavigationRenderer.prototype.makeFileDom = function(node) {
-        var fileNavigationRendererThis = this;
+        var that = this;
         var fileNavigationState = this.getFileNavigationState();
         var fileName = node.name;
 
-        var directoryLi = makeDom('li' , {
-            classList: 'directoryComponent-li'
-        });
-        
-        var directorySpan = makeDom('span' , {
-            classList: 'directoryComponent-column directoryComponent-dir-text icon-file',
-            innerHTML: `${fileName}`
-        });
+        var directoryLi = renderLi({class: 'directoryComponent-li'});
+        var directorySpan = renderSpan({class: 'directoryComponent-column directoryComponent-dir-text icon-file'
+                                       , text: `${fileName}`});
 
-        directorySpan.addEventListener('click', () => {
-            var dirPath = this.makeNewCurrRelativePath();
-
-            var csvOption = fileNavigationState.getFileOptionData();
-            if (fileName.indexOf('.' + csvOption.fileExtension) === -1) {
-                vpCommon.renderAlertModal(csvOption.fileExtension + ' 파일이 아닙니다');
+        directorySpan.click(function() {
+            var dirPath = that.makeNewCurrRelativePath();
+            var dataOption = fileNavigationState.getFileOptionData();
+            if (fileName.indexOf('.' + dataOption.fileExtension) === -1) {
+                vpCommon.renderAlertModal('Not ' + dataOption.fileExtension + ' file');
                 return;
             }
 
-            fileNavigationRendererThis.selectFile(dirPath, fileName);
-      
+            that.selectFile(dirPath, fileName);
         });
 
-        directoryLi.appendChild(directorySpan);
+        directoryLi.append(directorySpan);
         return directoryLi;
     }
 
     
-    FileNavigationRenderer.prototype.makeFolderOrFileDomArr = function(dirInfoArr, renderFolderType) {
+    FileNavigationRenderer.prototype.makeFolderOrFileDomArr = function(dirInfoArr) {
         var fileNavigationRendererThis = this;
 
         var folderArr = [];
@@ -204,7 +189,7 @@ define([
             var tempDom = null;
             // 디렉토리 정보가 폴더 일 경우
             if (nodeInfo.type === 'dir') {
-                tempDom = fileNavigationRendererThis.makeFolderDom(nodeInfo, renderFolderType);
+                tempDom = fileNavigationRendererThis.makeFolderDom(nodeInfo);
                 folderArr.push(tempDom);
             } else {
             // 디렉토리 정보가 파일 일 경우
@@ -222,13 +207,13 @@ define([
 
     FileNavigationRenderer.prototype.makeNewCurrRelativePath = function() {
         var fileNavigationState = this.getFileNavigationState();
-        var dirPath = fileNavigationState.getRelativePathStr();
+        var dirPath = fileNavigationState.getRelativeDir();
         /** 
          *  만약 현재 전체 path가 C:/Users/L.E.E/Desktop/Bit Python이라면,
          *  baseFolder 변수에 Bit Python가 저장됨
          *  즉 파일 네비게이션을 연 시점의 폴더가 baseFolder 
          */
-        var baseFolder = fileNavigationState.getBaseFolderStr();
+        var baseFolder = fileNavigationState.getBaseFolder();
         /** 
          *  만약 현재 전체 path가 C:/Users/L.E.E/Desktop/Bit Python이라면,
          *  Jupyter.notebook.notebook_path 는 'Desktop/Bit Python/Untitled4.ipynb' 
@@ -267,8 +252,8 @@ define([
     // loadingBar를 종료합니다.
     FileNavigationRenderer.prototype.finishLoadingBarAndSetCurrDirStr = function(currentDirStr, currentRelativePathStr) {
         var fileNavigationRendererThis = this;
-        fileNavigationRendererThis.fileNavigationState.setRelativePathStr(currentRelativePathStr);
-        fileNavigationRendererThis.fileNavigationState.setCurrentDirStr(currentDirStr);
+        fileNavigationRendererThis.fileNavigationState.setRelativeDir(currentRelativePathStr);
+        fileNavigationRendererThis.fileNavigationState.setCurrentDir(currentDirStr);
 
         $('.directoryComponent-container').find('#vp_loadingBar').remove();
     }
@@ -283,12 +268,12 @@ define([
         /** 이 메소드에서 사용할 state 데이터 가져오기 */
         var fileNavigationRendererThis = this;
         var fileNavigationState = this.getFileNavigationState();
-        fileNavigationState.setRelativePathStr(currentRelativePathStr);
-        fileNavigationState.setCurrentDirStr(currentDirStr);
+        fileNavigationState.setRelativeDir(currentRelativePathStr);
+        fileNavigationState.setCurrentDir(currentDirStr);
 
-        var notebookPathStr = fileNavigationState.getNotebookPathStr();
+        var notebookPathStr = fileNavigationState.getNotebookDir();
         var notebookPathStrLength = notebookPathStr.length;
-        var baseFolder = fileNavigationState.getBaseFolderStr();
+        var baseFolder = fileNavigationState.getBaseFolder();
         var notebookFolder = fileNavigationState.getNotebookFolder();
         /** 파일 네비게이션에 현재 path를 렌더링해서 보여주는 logic */
         var currentRelativePathStrArray = currentRelativePathStr.split('/');
@@ -303,11 +288,11 @@ define([
         currentRelativePathDomElement.append(basePathDomElement);
         basePathDomElement.click(function() {
             var dirObj = {
-                direction: 'to',
+                direction: NAVIGATION_DIRECTION_TYPE.TO,
                 destDir: notebookPathStr
             }
             // fileNavigation body에 현재 path의 폴더와 파일들 렌더링
-            executeKernelFromDirRightBody(dirObj, fileNavigationRendererThis);
+            executeKernelFromDirBody(dirObj, fileNavigationRendererThis);
         });
 
         var nestedLength = 0;
@@ -324,12 +309,12 @@ define([
                 var currentRelativePathStr = `${currentDirStr.substring(0, pathLength)}`;
      
                 var dirObj = {
-                    direction: 'to',
+                    direction: NAVIGATION_DIRECTION_TYPE.TO,
                     destDir: currentRelativePathStr
                 }
              
                 // fileNavigation body에 현재 path의 폴더와 파일들 렌더링
-                executeKernelFromDirRightBody(dirObj, fileNavigationRendererThis);
+                executeKernelFromDirBody(dirObj, fileNavigationRendererThis);
                 
             });
             currentRelativePathDomElement.append(spanElement);
@@ -345,10 +330,10 @@ define([
         var fileNavigationState = fileNavigationRendererThis.getFileNavigationState();
 
         /** 상대 경로 string을 자르고 붙이는 로직 */
-        var baseFolder = fileNavigationState.getBaseFolderStr();
-        var baseDirStr = fileNavigationState.getBaseDirStr();
-        var noteBookPathStr = fileNavigationState.getNotebookPathStr();
-        var currentDirStr = fileNavigationState.getCurrentDirStr();
+        var baseFolder = fileNavigationState.getBaseFolder();
+        var baseDirStr = fileNavigationState.getBaseDir();
+        var noteBookPathStr = fileNavigationState.getNotebookDir();
+        var currentDirStr = fileNavigationState.getCurrentDir();
         var noteBookPathStrLength = noteBookPathStr.length;
        
         var baseDirStrLength = baseDirStr.length;
@@ -412,7 +397,7 @@ define([
             $(fileNavigationRendererThis.fileResultState.fileInputId).val(`${filePathStr}`);
         }
 
-        vpCommon.renderSuccessMessage(`${filePathStr} 파일 선택 완료되었습니다`);
+        vpCommon.renderSuccessMessage(`${filePathStr} selection completed`);
         /** 장안태 추가. 파일 선택 완료시 문서 이벤트 발동 */
         if (fileNavigationState.getFileNavigationtype() === 'SAVE_FILE') {
             $(document).trigger({
